##  Setting Up Integrations for SaaS Discovery
Currently, integration is possible with the following SSO, CASB, and SASE systems:
  * [Microsoft Defender for Cloud Apps (MDCA)](https://help.sap.com/docs/leanix/ea/microsoft-defender-for-cloud-apps-mdca-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Set up an integration with Microsoft Defender for Cloud Apps to streamline the discovery of your SaaS applications.")
  * [Microsoft Entra ID](https://help.sap.com/docs/leanix/ea/microsoft-entra-id-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Set up an integration with Microsoft Entra ID to streamline the discovery of your SaaS applications.") (formerly Azure Active Directory)
  * [Netskope](https://help.sap.com/docs/leanix/ea/netskope-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Set up an integration with Netskope to streamline the discovery of your SaaS applications.")
  * [Okta](https://help.sap.com/docs/leanix/ea/okta-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the SAP LeanIX-Okta integration to automatically discover and manage SaaS applications.")
  * [Zscaler](https://help.sap.com/docs/leanix/ea/zscaler-integration-for-saas-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the SAP LeanIX-Zscaler integration to automatically discover and manage SaaS applications using Zscaler's ZIA API.")


To access the setup for these integrations, follow these steps:
  1. In the Administration area, select Integrations.
  2. Click Add integrations. All available integrations are shown on the resulting page.
  3. Click Configure on the needed integration.


For setup details, refer to the respective integration guides.
**Note**
We welcome your suggestions for additional integrations you'd like to see in the [SAP LeanIX Product Roadmap![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Froadmap.leanix.net%2Ftabs%2F10-on-roadmap%2Fsubmit-idea "https://roadmap.leanix.net/tabs/10-on-roadmap/submit-idea").
**Tip**
  * Both integration categories, SSO and CASB, offer unique benefits. CASB systems can uncover shadow or business-managed IT, while SSO integrations provide more detailed information about discovered SaaS. Therefore, we recommend connecting at least one integration per category.
  * Discovered SaaS applications are automatically linked to their corresponding fact sheets. If you prefer to manually review and link them, deactivate automatic linking in the discovery inbox settings before setting up the integrations. For more details, see [Automatic Linking of Discovered Applications to Fact Sheets](https://help.sap.com/docs/leanix/ea/saas-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c41a87a441014aa86ff57b7a5198f__automatic_linking).
